# Gamest

Gamest is a tool for keeping a record of time spent playing video games.

## Installation

Use pip to install gamest:

```
pip install gamest
```

Gamest may be launched by calling `gamest` from the command line. The executable
`gamest.exe` is located in python's `Scripts` folder, so a shortcut may be
placed wherever is convenient.

## Configuration

Out of the box, gamest will track runtime of desired apps. To add an app to be
tracked, start the app, then click 'Pick Game`, choose the app from the list,
and click 'Pick Game' to select it. In most cases, no advanced settings will be
required, so click 'Add Game' to finish adding the app to the database. In the
future, the app will be automatically detected whenever it is running.

Gamest may be configured by clicking the 'Settings' button on the program
window. Any installed plugins may be configured in the same way.

## License

Copyright (C) 2018  Tracy Poff

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

## Credits

* Icon: clipboard by Naveen from the Noun Project
